Plugin

Trait Plugin 

pub trait Plugin {
    // Required methods
    fn id(&self) -> &'static str;
    fn install(&self, registry: &mut PluginRegistry) -> Result<(), &'static str>;
}
A plugin is the unit of composition for node bundles.

Required Methods

fn id(&self) -> &'static str

Stable identifier for the plugin (e.g., bundle name).

fn install(&self, registry: &mut PluginRegistry) -> Result<(), &'static str>

Install node descriptors and handlers into a plugin registry.

Implementors