pub trait Plugin { // Required methods fn id(&self) -> &'static str; fn install(&self, registry: &mut PluginRegistry) -> Result<(), &'static str>; }
A plugin is the unit of composition for node bundles.
Stable identifier for the plugin (e.g., bundle name).
Install node descriptors and handlers into a plugin registry.